/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>

#ifndef _NO_PROTO 
void XmgfEvent(Widget w,XtPointer closure,XEvent *Xmgfevent,int *done);
void XmgfEventList(Widget w,XtPointer closure,XEvent *Xmgfevent,int *done);
void XmgfWindowEvent(Widget w,XtPointer closure,XEvent *Xmgfevent,int *done);
#else 
void XmgfEvent();
void XmgfEventList();
void XmgfWindowEvent();
#endif 
